<?php

namespace JBP\Elements\Elements\Options;

use Jeg\Element\Elements\Elements_Option_Abstract;

/**
 * Class Post_Comment_Option
 * @package JBP\Elements\Elements\Options
 */
class Post_Comment_Option extends Elements_Option_Abstract {

	/**
	 * Show color scheme flag for element.
	 *
	 * @return bool
	 */
	public function show_color_scheme() {
		return false;
	}

	/**
	 * Compatibility column
	 *
	 * @return array
	 */
	public function compatible_column() {
		return [ esc_html__( 'All Columns', 'jblog-elements' ) ];
	}

	/**
	 * Element name
	 *
	 * @return string
	 */
	public function get_element_name() {
		return esc_html__( 'JBlog - Post Comment', 'jblog-elements' );
	}

	/**
	 * Element category
	 *
	 * @return string
	 */
	public function get_category() {
		return esc_html__( 'Post Template', 'jblog-elements' );
	}

	/**
	 * Element options
	 */
	public function set_options() {
		$this->set_style_option();
		$this->set_element_options();

		unset( $this->options['column_width'] );
	}

	/**
	 * Option segments
	 */
	public function set_segments() {
		$this->segments['general'] = [
			'name'     => esc_html__( 'General', 'jblog-elements' ),
			'priority' => 10,
		];
		$this->set_style_segment();
	}

	/**
	 * Set element option
	 */
	public function set_element_options() {
		$this->options['style'] = [
			'type'        => 'select',
			'title'       => esc_html__( 'Comment Style', 'jblog-elements' ),
			'description' => esc_html__( 'Set style for the post comment.', 'jblog-elements' ),
			'default'     => '1',
			'segment'     => 'general',
			'options'     => [
				'1' => esc_html__( 'Style 1', 'jblog-elements' ),
				'2' => esc_html__( 'Style 2', 'jblog-elements' ),
			]
		];

		$this->options['toggle'] = [
			'type'        => 'checkbox',
			'title'       => esc_html__( 'Toggle Comment', 'jblog-elements' ),
			'description' => esc_html__( 'Enable toggle comment.', 'jblog-elements' ),
			'segment'     => 'general',
		];

		$this->options['toggle_default'] = [
			'type'        => 'select',
			'title'       => esc_html__( 'Default Toggle', 'jblog-elements' ),
			'description' => esc_html__( 'Set default show or hide the comment.', 'jblog-elements' ),
			'default'     => 'hide',
			'segment'     => 'general',
			'options'     => [
				'show' => esc_attr__( 'Show Comment', 'jblog-elements' ),
				'hide' => esc_attr__( 'Hide Comment', 'jblog-elements' ),
			],
			'dependency'  => [
				[
					'field'    => 'toggle',
					'operator' => '==',
					'value'    => true,
				],
			]
		];

		$this->options['full'] = [
			'type'        => 'checkbox',
			'title'       => esc_html__( 'Fullwidth Toggle', 'jblog-elements' ),
			'description' => esc_html__( 'Enable fullwidth toggle comment.', 'jblog-elements' ),
			'segment'     => 'general',
			'dependency'  => [
				[
					'field'    => 'toggle',
					'operator' => '==',
					'value'    => true,
				],
			]
		];
	}
}
